@@ -12,9 +12,11 @@
 
 #include <QString>
 
+#include <memory>
+
 namespace Baloo {
 
-class Result;
+class ResultList;
 class ResultIteratorPrivate;
 
 /**
@@ -26,23 +28,16 @@ public:
     ResultIterator(ResultIterator &&rhs);
     ~ResultIterator();
 
-#if BALOO_CORE_BUILD_DEPRECATED_SINCE(5, 55)
-    /**
-     * @deprecated Since 5.55. Do not use this function, ResultIterator is not copyable, move it if needed
-     */
-    BALOO_CORE_DEPRECATED_VERSION(5, 55, "Do not use. ResultIterator is not copyable, move it if needed.")
-    ResultIterator(const ResultIterator& rhs);
-#else
     ResultIterator(const ResultIterator& rhs) = delete;
-#endif
     ResultIterator &operator=(const ResultIterator& rhs) = delete;
 
     bool next();
     QString filePath() const;
+    QByteArray documentId() const;
 
 private:
-    ResultIterator(const QStringList& results);
-    ResultIteratorPrivate* d;
+    BALOO_CORE_NO_EXPORT explicit ResultIterator(ResultList&& res);
+    std::unique_ptr<ResultIteratorPrivate> d;
 
     friend class Query;
 };
